Converts dates to a list of numbers representing the number of days from the start of followup until the start of the infectious period.
MCMC_date(dates,start_date=NULL)A list of extended natural numbers.
A list of dates. May be of character, numeric, or date class.
The start date of follow up
Covrerts dates to days of followup until the start of the infectious period. Missing data are set to infinity and are assumed susceptible during followup.