Computes the community attack rate for a a cohort using the
value of a call to household_transmission.
community_attack_rate(SIRmcmc,probs=c(0.5,0.025,0.975))An array of community attack rates. The first dimension is the
value of epsilon in SIRmcmc. The second dimension
is the posterior probability in the probs argument
The value of a call to household_transmission.
A numeric vector of the quantiles of the posterior distribution. The default is the median and the central 95% credible region.
Computes the posterior probability distribution of the community
attack rate from the Metropolis algoritm. Returns quantiles of the
distribution specified in the probs argument.