Compute the prior probability of alpha, beta, gamma, and epsilon
prior(alpha, beta, gamma, epsilon, esteps, params = list(alpha =
list(location = 0, scale = 2), beta = list(shape = 0.01, rate = 0.01),
gamma = list(shape = 0.01, rate = 0.01),
epsilon = list(location = 0, scale = 2)))A probability of the model parameters under the prior distributions.
A number. The logarithm of alpha follows a logistic distribution.
A number. beta follows a gammadistribution.
A number. gamma follows a gamma distribution.
A number. The logarithm of epsilon follows a logistic distribution.
A number in (0,1). Used for logic as to whether to compute the prior probability of epsilon (1) or not (0).
A list of parameters for the prior distributions.