Using the value of a call to
household_transmission, computes the secondary attack
rate for households.
secondary_attack_rate(household_size,SIRmcmc,probs=c(0.5,0.025,0.975))An array with secondary attack rates.
The first dimension of the array is the household size.
The second dimension of the array is the quantiles of the posterior
distribution in the probs argument.
The third dimension of the array is the value of epsilon in SIRmcmc.
A numeric vector containing the number of people in a household.
The value of a call to household_transmission.
A numeric vector of the quantiles of the posterior distribution. The default is the median and the central 95% credible region.
Computes the posterior probability distribution of the secondary
attack rate from the Metropolis algorithm. Returns quantiles of the
distribution specified in the probs argument.