Learn R Programming

SIRmcmc (version 1.1.1)

unifprior: A uniform prior on the model parameters

Description

Compute a uniform prior on alpha, beta, gamma, and epsilon

Usage

unifprior(alpha, beta, gamma, epsilon, esteps, UB = 1000, LB = 0.01)

Value

If all the model parameters are between the lower bound and the upper bound, then unifprior returns 1. Otherwise, unifprior returns 0.

Arguments

alpha

A number compared to the upper bound UB and the lower bound LB.

beta

A number compared to the upper bound UB and the lower bound LB.

gamma

A number compared to the upper bound UB and the lower bound LB.

epsilon

A number compared to the upper bound UB and the lower bound LB.

esteps

A number in (0,1). Used for logic as to whether to compute the prior probability of epsilon (1) or not (0).

UB

A number used as an upper bound on the model parameters.

LB

A number used as a lower bound on the model parameters.

See Also

dlogis dgamma household_transmission prior