Compute a uniform prior on alpha, beta, gamma, and epsilon
unifprior(alpha, beta, gamma, epsilon, esteps, UB = 1000, LB = 0.01)If all the model parameters are between the lower bound and the upper bound, then unifprior returns 1. Otherwise, unifprior returns 0.
A number compared to the upper bound UB and the lower bound LB.
A number compared to the upper bound UB and the lower bound LB.
A number compared to the upper bound UB and the lower bound LB.
A number compared to the upper bound UB and the lower bound LB.
A number in (0,1). Used for logic as to whether to compute the prior probability of epsilon (1) or not (0).
A number used as an upper bound on the model parameters.
A number used as a lower bound on the model parameters.